From 8c13e8877c29497ff36fb724b5e940ddc15c2c90 Mon Sep 17 00:00:00 2001
From: Nick Kew
Date: Tue, 15 Sep 2009 21:41:05 +0000
Subject: [PATCH] Change Fallback to FallbackResource after extensive
discussion with wrowe and DrBacchus.
git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@815502 13f79535-47bb-0310-9956-ffa450edef68
---
CHANGES | 2 +-
docs/manual/mod/mod_dir.xml | 6 +++---
modules/mappers/mod_dir.c | 4 ++--
3 files changed, 6 insertions(+), 6 deletions(-)
diff --git a/CHANGES b/CHANGES
index 0d6494c900..8e7e229fd3 100644
--- a/CHANGES
+++ b/CHANGES
@@ -105,7 +105,7 @@ Changes with Apache 2.3.3
*) mod_alias: ensure Redirect issues a valid URL.
PR 44020 [HÃ¥kon Stordahl ]
- *) mod_dir: add Fallback directive, to enable admin to specify
+ *) mod_dir: add FallbackResource directive, to enable admin to specify
an action to happen when a URL maps to no file, without resorting
to ErrorDocument or mod_rewrite. PR 47184 [Nick Kew]
diff --git a/docs/manual/mod/mod_dir.xml b/docs/manual/mod/mod_dir.xml
index 8f52dc9849..28d08e4a4e 100644
--- a/docs/manual/mod/mod_dir.xml
+++ b/docs/manual/mod/mod_dir.xml
@@ -157,9 +157,9 @@ a directory
-Fallback
+FallbackResource
Define a default URL for requests that don't map to a file
-Fallback local-url
+FallbackResource local-url
None - httpd will return 404 (Not Found)
server configvirtual host
directory.htaccess
@@ -169,7 +169,7 @@ a directory
in your filesystem, and would otherwise return HTTP 404 (Not Found).
For example
- Fallback not-404.php
+ FallbackResource not-404.php
will cause requests for non-existent files to be handled by
not-404.php
, while requests for files that exist
diff --git a/modules/mappers/mod_dir.c b/modules/mappers/mod_dir.c
index d9efd539db..6ce3945d73 100644
--- a/modules/mappers/mod_dir.c
+++ b/modules/mappers/mod_dir.c
@@ -83,7 +83,7 @@ static const char *configure_slash(cmd_parms *cmd, void *d_, int arg)
static const command_rec dir_cmds[] =
{
- AP_INIT_TAKE1("Fallback", ap_set_string_slot,
+ AP_INIT_TAKE1("FallbackResource", ap_set_string_slot,
(void*)APR_OFFSETOF(dir_config_rec, dflt),
DIR_CMD_PERMS, "Set a default handler"),
AP_INIT_RAW_ARGS("DirectoryIndex", add_index, NULL, DIR_CMD_PERMS,
@@ -128,7 +128,7 @@ static int fixup_dflt(request_rec *r)
if (name_ptr == NULL) {
return DECLINED;
}
/* XXX: if Fallback points to something that doesn't exist,
* this may recurse until it hits the limit for internal redirects
* before returning an Internal Server Error.
*/
@@ -128,7 +128,7 @@ static int fixup_dflt(request_rec *r)
return DECLINED;
}
- /* XXX: if Fallback points to something that doesn't exist,
+ /* XXX: if FallbackResource points to something that doesn't exist,
* this may recurse until it hits the limit for internal redirects
* before returning an Internal Server Error.
--
2.40.0